#! /usr/bin/env python
########################################################################################################################
# Description:  This just sets up some variables, imports etc. for interactive testing                                 #
# Author: Jasmine-Arabella Post                                                                                        #
# Date Started: 20161020                                                                                               #
########################################################################################################################
# NOTE: as of 20190809 this does not work with test environment files or test opitonal files


#########################
#      Setup Stuff      #
#########################
import util
import logging
import datetime
import os
from util import *

# setup a time stamp
now = datetime.datetime.now()
myTime = now.strftime("%Y%m%d-%H%M%S")



#   Test Environment Variables
#=============================
# the following is needed to replace the work of the test runner.
envFile = "qa-environment.csv"
cwd = os.getcwd()
path2file = cwd + "/pyrest/" + envFile
os.environ["pyTestEnv"] = path2file
os.environ["pyTestFile"] = "Adhock"
os.environ["pyTestDebug"] = 'true'


########################################
#           Setup Logging              #
########################################
# create time stamp for logging
now = datetime.datetime.now()
time = now.strftime("%d%H%M%S")
number_name = time

# build loggers
myLogger = logging.getLogger()

# Check to see if we are using DEBUG or INFO
if os.getenv("pyTestDebug"):
    myLogger.setLevel(logging.DEBUG)
    l_level = "DEBUG"
else:
    myLogger.setLevel(logging.INFO)
    l_level = "INFO"

# Get full path to log file
testfilename =   os.environ["pyTestFile"].strip(".py").replace('/','-')
log_file_name = "logs/{time}-{filename}.log".format(time=time, filename=testfilename)

log_handler = logging.FileHandler(log_file_name)
log_handler.setLevel(logging.NOTSET)
myLogger.addHandler(log_handler)

# build log file header
formatter0 = logging.Formatter()
log_handler.setFormatter(formatter0)
myLogger.info("============================================================")
myLogger.info("  The following is some basic info on this log file")
myLogger.info("------------------------------------------------------------")
myLogger.info("The log file is: " + log_file_name)
myLogger.debug("The environment variables are: " + str(os.environ))

# see if we have optional varialbes and add them
if os.getenv("pyTestVars"):
      varsFile = os.environ["pyTestVars"]
      myLogger.debug("The optional variables CSV file is: " + varsFile)
      get_additional_var()

# finish the log header
formatter1 = logging.Formatter('Log file created at: %(asctime)s \nThe test file is: ' +  os.environ["pyTestFile"]  + '\nThe log level is: ' + l_level)
log_handler.setFormatter(formatter1)
myLogger.info("")

# setup header for regular logging statements
log_handler.setFormatter(formatter0)
myLogger.info("\nDate        Time         Line   Level     Message")
myLogger.info("============================================================")

# set format for regular logging statements
formatterFinal = logging.Formatter('%(asctime)s - %(lineno)d  - %(levelname)s - %(message)s')
log_handler.setFormatter(formatterFinal)


#   Some helper functions
#========================
def newName():
  """
  A function to create a name with a time stamp
  """
    now = datetime.datetime.now()
    nowtime = now.strftime("%f")
    returnString = "JP-" + str(nowtime)
    return returnString


############################################################
#          Setup is done, start testing                    #
############################################################
# the following two lines allow you to import as if you are
# above the pyrest folder
import repackage
repackage.up()

from sample_tests.apis import WP_APIs

myEnv = "https://my_wp-mfpost902951.codeanyapp.com"


# End of File
# ==============================================================================



#! /usr/bin/env python
########################################################################################################################
# Description: atr is the "API Test Runner" to run API tests via py.tesrt                                                         #
# Author: Jasmine-Arabella Post                                                                                        #
# Date Started:  20161028                                                                                              #
########################################################################################################################
print("this is atr")


if __name__ == "__main__":
    # this won't be run when imported
    #########################
    #      Setup Stuff      #
    #########################
    import os
    import argparse
    import logging
    from argparse import RawTextHelpFormatter
    from subprocess import call
    import re



    #   Process CLI Options
    #======================
    app_description = """ATR is API Test Runner
    ----------------------
    This test runner will take a py.test formatted file
    and run it in the given environment.
    """
    parser = argparse.ArgumentParser(description=app_description, formatter_class=RawTextHelpFormatter)

    # Required parameters
    required = parser.add_argument_group("Required")
    required.add_argument('-e', '--environment', dest='env', action="store", default="qa",
                          choices=['dev', 'qa', 'prod'],
                          help="This sets the server environment the test will be run against")
    required.add_argument('-f', '--file2test', dest='test_file', action='store', required=True,  help="The file to test (jmx).")

    # optional parameters
    parser.add_argument('-d', '--debug', dest="debug", action="store_true",  default=False,
                        help="This option sets logging to debug mode. The default is INFO")
    parser.add_argument('-v', '--variables', dest="vars", action="store",
                        help="This option allows you to use a CSV file to add more global variables to your test suite")

    userOptions = parser.parse_args()


    #   Set Environment to Test In
    #=============================
    # build path to file
    envFile = userOptions.env + "-environment.csv"
    cwd = os.getcwd()

    # need to get the path out of test_file
    # then replayc /pyrest/ with that
    path4test = os.path.dirname(userOptions.test_file)
    path2file = "{}/{}/env/{}".format(cwd, path4test, envFile)

    # Verify path to environment configuration file
    if not os.path.isfile(path2file):
        print( "Could not find '" + str(path2file) + "', the environment file.  There for tests can not be run.")
        exit()

    # Set path file to OS env var
    os.environ["pyTestEnv"] = path2file



    #    Set Log Level
    #=================
    # Defaults to INFO, but can be set to DEBUG
    if userOptions.debug:
        os.environ["pyTestDebug"] = 'true'


    #   Set Other Variables
    #======================
    if userOptions.vars:
        os.environ["pyTestVars"] = userOptions.vars


    ########################################
    #           Call py.test               #
    ########################################

    # check for specific test
    look4test = re.compile('::.*')
    bearFile = look4test.sub("", userOptions.test_file)


    # Verify path to test file
    if not os.path.isfile(bearFile):
        print( "Could not find '" + bearFile + "', the test file.  There for tests can not be run.")
        exit()

    os.environ["pyTestFile"] = userOptions.test_file

    # Call py.test
    call(["py.test","-v", userOptions.test_file])














# End of File
# ==============================================================================
